#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 network-run
version:              0.3.1
visibility:           public
id:                   network-run-0.3.1-KPEp8eIJKOW6GoDbdTIo53
key:                  network-run-0.3.1-KPEp8eIJKOW6GoDbdTIo53
license:              BSD-3-Clause
maintainer:           kazu@iij.ad.jp
author:               Kazu Yamamoto
synopsis:             Simple network runner library
description:          Simple functions to run network clients and servers.
category:             Network
abi:                  eb52c5217b8bdc645f5445fe2876c4df
exposed:              True
exposed-modules:
    Network.Run.TCP Network.Run.TCP.Timeout Network.Run.UDP

hidden-modules:       Network.Run.Core
import-dirs:          /usr/lib/ghc-9.6.6/site-local/network-run-0.3.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/network-run-0.3.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/network-run-0.3.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-network-run
hs-libraries:         HSnetwork-run-0.3.1-KPEp8eIJKOW6GoDbdTIo53
depends:
    base-4.18.2.1 bytestring-0.11.5.3
    network-3.1.4.0-FxgQMUnc8In23QMgSfNDtL
    time-manager-0.0.1-2DwFshjwJJJ5P8MTje8mf5

haddock-interfaces:   /usr/share/doc/haskell-network-run/html/network-run.haddock
haddock-html:         /usr/share/doc/haskell-network-run/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

